function [g_alpha, g_dist, g_pos, g_mask] = getLocalConsistAlphaGrad(alpha, thr, border)

if (~exist('thr','var') || isempty(thr))
    thr = 1e10;
end

[h w c] = size(alpha);

dx = zeros(h,w);
dy = zeros(h,w);
dx(2:h,2:w) = alpha(2:h,2:w) - alpha(2:h,1:w-1);
dy(2:h,2:w) = alpha(2:h,2:w) - alpha(1:h-1,2:w);

win_size = 3; % local consistency window size
win_filter = ones(win_size, win_size);
nn = 1 ./ (dx.*dx + dy.*dy + 0.00001 );

% assume the intersection coordinate is (x,y), it should satisify 
% dx*x + dy*y = 1, we compute the  min(sum(dx*x+dy*y-1)^2/(dx*dx+dy*dy))
% extend it as    ax^2+cy^2+2bxy+2dx+2ey+f
a = conv2(dx.*dx.*nn, win_filter, 'same');
b = conv2(dx.*dy.*nn, win_filter, 'same');
c = conv2(dy.*dy.*nn, win_filter, 'same');
d = - conv2(dx.*nn, win_filter, 'same');
e = - conv2(dy.*nn, win_filter, 'same');
f = conv2(nn, win_filter, 'same');

delta = a.*c - b.*b;
mask = delta > 0.0001;
% solution is x = -(dc-eb)/(ac-bb), y = - (ae-db)/(ac-bb);
% min value is dx+ey+f
solx = (e.*b-d.*c)./(delta+0.00001);
soly = (b.*d-a.*e)./(delta+0.00001);
min_val = mask .* (d.*solx + e.*soly + f) + (1-mask) .* ( f - d.*d./a );

%remove pixels in the pure alpha region
mask = min(alpha<0.98, alpha>0.02);
mask = mask .* (min_val<thr);

nb_valid = 0;
g_alpha = zeros(h*w,2);
g_dist = zeros(h*w,1);
g_pos = zeros(h*w,2);
for yy=border+1:h-border
    for xx = border+1:w-border
        if mask(yy,xx) < 1 
            continue;
        end
        nb_valid = nb_valid + 1;
        g_alpha(nb_valid, 1) = dy(yy,xx);
        g_alpha(nb_valid, 2) = dx(yy,xx);
        g_dist(nb_valid) = min_val(yy,xx);
        g_pos(nb_valid, 1) = yy;
        g_pos(nb_valid, 2) = xx;
    end
end

g_mask = mask(border+1:h-border, border+1: w-border);
g_alpha = g_alpha(1:nb_valid,:);
g_dist = g_dist(1:nb_valid);
g_pos = g_pos(1:nb_valid,:);