%visualization in the Hough domain (motion parameter space)
% g_alpha:  alpha channel gradient, y gradient first
% range:    half image size of the Hough domain
% scale:    scaling factor for the Hough domain image
function img_show = visualizeHough(g_alpha, range, scale)

img_show = zeros(2*range*scale+1, 2*range*scale+1);
matx = repmat(-range:1/scale:range, 2*range*scale+1, 1);
maty = repmat([-range:1/scale:range]',1, 2*range*scale+1);

% line width param
thr = 0.2;

for idx=1:size(g_alpha, 1)
    % each point votes for two parallel lines
    yy = g_alpha(idx,1);
    xx = g_alpha(idx,2);
    dis = ( matx * xx + maty * yy - 1 ) / sqrt(xx*xx + yy*yy);
    img_show = img_show + double(abs(dis) < thr);
    
    yy = -yy;
    xx = -xx;
    dis = ( matx * xx + maty * yy - 1 ) / sqrt(xx*xx + yy*yy);
    img_show = img_show + double(abs(dis) < thr);
end

figure; imshow(1-img_show/max(img_show(:))); title('Hough voting on the motion parameter space');